/**
 * Node.js built-in file system module.
 *
 * Bun, Deno support node:fs/promises so we don't need to re-implement it.
 *
 * @module
 */ "use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "fs", {
    enumerable: true,
    get: function() {
        return _promises.default;
    }
});
const _promises = /*#__PURE__*/ _interop_require_default(require("node:fs/promises"));
function _interop_require_default(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
