import pathe from "pathe";
import { fs } from "./fs/memory.js";
export { fs, pathe as path };
export interface SHA256 {
    update(data: string | Uint8Array): void;
    digest(): string;
}
export declare const EOL = "\n";
export declare function ok(value: unknown, message?: string): asserts value;
export declare function createSHA256(): SHA256;
export declare function randomUUID(): string;
declare const ReadableStream: any;
declare const TransformStream: any;
declare const WritableStream: any;
export { AsyncLocalStorage, CustomEvent, getEnv, setEnvs } from "./utils.js";
export { ReadableStream, TransformStream, WritableStream };
