/// <reference types="node" resolution-mode="require"/>
/// <reference types="node" resolution-mode="require"/>
/// <reference types="node" resolution-mode="require"/>
/// <reference types="node" resolution-mode="require"/>
/// <reference types="node" resolution-mode="require"/>
/**
 * This module is under Node.js environment.
 * It provides a set of APIs to interact with the file system, streams, and other Node.js built-in modules.
 *
 * Use this under "node" condition,
 *
 * For example:
 * ```shell
 * node -e "const env = require('@llamaindex/env');"
 * ```
 *
 * @module
 */
import { ok } from "node:assert";
import { randomUUID } from "node:crypto";
import { EOL } from "node:os";
import path from "node:path";
import { ReadableStream, TransformStream, WritableStream } from "node:stream/web";
import { fs } from "./fs/node.js";
import type { SHA256 } from "./polyfill.js";
export declare function createSHA256(): SHA256;
export { AsyncLocalStorage, CustomEvent, getEnv, setEnvs } from "./utils.js";
export { EOL, ReadableStream, TransformStream, WritableStream, fs, ok, path, randomUUID, };
