/**
 * Memory file system, used by edge runtime, worker runtime which doesn't have access to the file system.
 *
 * @module
 */ // @ts-expect-error
"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "fs", {
    enumerable: true,
    get: function() {
        return fs;
    }
});
const _index = /*#__PURE__*/ _interop_require_default(require("./memfs/index.js"));
function _interop_require_default(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
const fs = _index.default.promises;
